@@ -409,11 +409,14 @@ class Database(object):
 			"default:str,dict,list,int,float":default,
 			"save:bool":save,})
 		if not response.success: return response
-		content = self.DataObject(path=f"{self.path}/{path}", aes=self.aes)
+		response = self.load(path=path, default=default)
+		if not response.success: return response
+		format, content = response.unpack(["format", "content"])
 		response = content.check(default=default, save=save)
 		if not response.success: return response
 		return r3sponse.success(f"Successfully checked content {path}.", {
 			"content":content,
+			"format":format,
 		})
 	def load(self, 
 		# the subpath of the content (! param number 1).
@@ -425,12 +428,29 @@ class Database(object):
 		response = r3sponse.check_parameters({
 			"path:str":path,})
 		if not response.success: return response
-		content = self.DataObject(path=f"{self.path}/{path}", default=default, aes=self.aes)
-		response = content.load()
-		if not response.success: return response
-		return r3sponse.success(f"Successfully loaded content [{path}].", {
-			"content":content,
-		})
+		path = gfp.clean(f"{self.path}/{path}", remove_last_slash=True, remove_double_slash=True)
+		if not os.path.exists(str(path)):
+			return r3sponse.error(f"Specified path [{path}] does not exist.")
+		try:
+			format, _ = unpack(Files.load(path))
+		except Exception as e: return r3sponse.error(f"Failed to load content {path}, {e}.")
+		if format in ["list", "Array"]:
+			return r3sponse.success(f"Successfully parsed {path}.", {
+				"format":"Array",
+				"content":self.Array(path=path, default=default, aes=self.aes),
+			})
+		elif format in ["dict", "Dictionary"]:
+			return r3sponse.success(f"Successfully parsed {path}.", {
+				"format":"Dictionary",
+				"content":self.Dictionary(path=path, default=default, aes=self.aes),
+			})
+		elif format in ["file", "File"]:
+			return r3sponse.success(f"Successfully parsed {path}.", {
+				"format":"File",
+				"content":self.File(path=path, default=default, aes=self.aes),
+			})
+		else:
+			return r3sponse.error(f"Unknown format [{format}] for path [{path}].")
 	def save(self, 
 		# the content object (! param number 1).
 		content=None,
@@ -442,10 +462,10 @@ class Database(object):
 		response = content.save()
 		if not response.success: return response
 		return r3sponse.success(f"Successfully saved content {path}.")
-	
-	# a data object.
-	class DataObject(object):
-		def __init__(self, 
+
+	# a file data object
+	class File(File):
+		def __init__(self,
 			# the path.
 			path=None, 
 			# the default data, specify to call self.check() automatically.
@@ -454,57 +474,9 @@ class Database(object):
 			aes=None,
 		):
 			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
-			self.fp = self.file_path = FilePath(self.path)
+			self.base = FilePath(self.path).base()
 			self.aes = aes
-			self.base = FilePath(path).base()
-			self.content = None
-			self.format = None
-			self.loaded = False
-			if default != None:
-				response = self.check(default=default, save=True)
-				if not response.success: raise ValueError(response.error)
-		# check the content.
-		def check(self, default=None, save=True):
-			response = r3sponse.check_parameters({
-				"default:dict,list,str,float,int":default,
-				"save:bool":save,})
-			if not response.success: return response
-			if not Files.exists(self.base): os.system(f"mkdir -p {self.base}")
-			do = False
-			if not Files.exists(self.path): 
-				do = True
-				new = default
-			else:
-				response = self.load()
-				if not response.success: return response
-				old_format = Formats.get(self.content, serialize=True)
-				new_format = Formats.get(default, serialize=True)
-				#if old_format != new_format:
-				#	return r3sponse.error(f"Mismatching formats, old format: {old_format}, new format: {new_format}.")
-				if new_format == "dict":
-					new = Dictionary(self.content).check(default=default, save=False)
-					print("NEW:",new,"VS",self.content,"=",new != Dictionary(self.content))
-					if new != Dictionary(self.content): do = True
-				elif new_format == "list":
-					old = list(self.content)
-					new = list(default)
-					for i in default:
-						new.append(i)
-					if new != old: do = True
-				elif new_format in ["str", "float", "int"]:
-					old = str(self.content)
-					new = str(default)
-					if new != old: do = True
-				else: return r3sponse.error(f"Unsupported new format: {new_format}.")
-			if do:
-				self.content = Formats.initialize(new)
-				self.format = Formats.get(Formats.denitialize(self.content), serialize=True)
-				if save:
-					self.loaded = True
-					response = self.save()
-					if not response.success: return response
-			return r3sponse.success(f"Successfully checked the content of {self.path}.")
-		# load & decrypt.
+			File.__init__(self, path=self.path)
 		def load(self):
 			try:
 				format, content = unpack(Files.load(self.path))
@@ -512,145 +484,103 @@ class Database(object):
 			response = self.aes.decrypt(content.encode())
 			if not response.success: return response
 			decrypted = response.decrypted.decode()
-			if format in ["dict", "list", "Dictionary", "Array"]:
-				try:
-					content = json.loads(decrypted)
-				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
-			elif format in ["int"]:
-				try:
-					content = int(decrypted)
-				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
-			elif format in ["float"]:
-				try:
-					content = float(decrypted)
-				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
-			elif format in ["str"]:
-				try:
-					content = str(decrypted)
-				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
-			else: return r3sponse.error(f"Unsupported format: {format}.")
-			self.content = Formats.initialize(content)
+			self.data = decrypted
 			self.format = format
 			self.loaded = True
 			return r3sponse.success(f"Successfully loaded content {self.path}.")
-		# save & encrypt.
 		def save(self):
 			if not self.loaded:
 				return r3sponse.error("The data object is not loaded yet, you must call content.load() first.")
-			if self.format in ["list", "dict", "Dictionary", "Array"]:
-				try:
-					content = json.dumps(Formats.denitialize(self.content))
-				except Exception as e: return r3sponse.error(f"Failed to dump content {self.path}, {e}.")
-			elif self.format in ["str", "int", "float"]:
-				content = str(self.content)
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the <self.save()> function.")
+			content = Formats.denitialize(self.content)
 			response = self.aes.encrypt(content)
 			if not response.success: return response
 			try:
 				content = utils.__save_bytes__(str(self.path), f"{self.format} ".encode()+response.encrypted)
 			except Exception as e: return r3sponse.error(f"Failed to save content {self.path}, {e}.")
 			return r3sponse.success(f"Successfully saved content {self.path}.")
-		# iterate over self keys & variables.
-		def items(self):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["list", "Array"]:
-				return self.content
-			elif self.format in ["dict", "Dictionary"]:
-				return self.content.items()
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the <self.items()> function.")
-		def keys(self):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["list", "Array"]:
-				return self.content
-			elif self.format in ["dict", "Dictionary"]:
-				return list(self.content.keys())
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the <self.keys()> function.")
-		def values(self):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict", "Dictionary"]:
-				return list(self.content.values())
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the <self.values()> function.")
-		def dict(self, serialize=False):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict", "Dictionary"]:
-				
-				dictionary = {}
-				for key, value in self.content.items():
-					if serialize:
-						if isinstance(value, object):
-							value = str(value)
-						elif value == "True": value = True
-						elif value == "False": value = False
-						elif value == "None": value = None
-					dictionary[key] = value
-				return dictionary
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the <self.dict()> function.")
-		# assign self variables by dictionary.
-		def assign(self, dictionary):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if not isinstance(dictionary, (dict, Dictionary)):
-				raise TypeError("You can only self assign with a dictionary as parameter.")
-			if self.format in ["dict", "Dictionary"]:
-				for key,value in dictionary.items():
-					self.content[key] = value
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the <self.assign()> function.")
-		# count items.
-		def __len__(self):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["list", "Array"]:
-				return len(self.content)
-			elif self.format in ["dict", "Dictionary"]:
-				return len(self.content.keys())
-			elif self.format in ["str", "int", "float"]:
-				return len(str(self.content))
-			else:
-				return f"<encrypti0n.aes.Database.DataObject {self.path} content: {self.content}>"
-		# support item assignment.
-		def __setitem__(self, key, value):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict", "Dictionary"]:
-				setattr(self.content, key, value)
-			elif self.format in ["str"] and isinstance(key, (int, Integer)):
-				self.content[int(key)] = value
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the self[""] item assignment.")
-		def __getitem__(self, key):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict", "Dictionary"]:
-				return getattr(self.content, key)
-			elif self.format in ["str"] and isinstance(key, (int, Integer)):
-				return self.content[int(key)]
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the self[""] item assignment.")
-		def __delitem__(self, key):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict", "Dictionary"]:
-				delattr(self.content, key)
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the self[""] item assignment.")
-		# string format.
-		def __str__(self):
-			return str(self.content)
-		# repr.
-		def __repr__(self):
-			if not self.loaded: 
-				return f"<encrypti0n.aes.Database.DataObject {self.path} content: not loaded yet>"
-			elif self.format in ["dict"]:
-				return f"<encrypti0n.aes.Database.DataObject {self.path} content: {self.dict(serialize=True)}>"
-			else:
-				return f"<encrypti0n.aes.Database.DataObject {self.path} content: {self.content}>"
-		def json(self,):
-			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict", "Dictionary"]:
-				return self.dict(serialize=True)
-			else:
-				raise ValueError(f"DataObject with format {self.format} does not support the <self.json()> function.")
+
+	# a array data object
+	class Array(Array):
+		def __init__(self,
+			# the path.
+			path=None, 
+			# the default data, specify to call self.check() automatically.
+			default=None,
+			# the aes object.
+			aes=None,
+		):
+			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
+			self.base = FilePath(self.path).base()
+			self.aes = aes
+			Array.__init__(self, path=self.path)
+		def load(self):
+			try:
+				format, content = unpack(Files.load(self.path))
+			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
+			response = self.aes.decrypt(content.encode())
+			if not response.success: return response
+			decrypted = response.decrypted.decode()
+			try:
+				content = json.loads(decrypted)
+			except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
+			self.array = content
+			self.format = format
+			self.loaded = True
+			return r3sponse.success(f"Successfully loaded content {self.path}.")
+		def save(self):
+			if not self.loaded:
+				return r3sponse.error("The data object is not loaded yet, you must call content.load() first.")
+			try:
+				content = json.dumps(Formats.denitialize(self.array))
+			except Exception as e: return r3sponse.error(f"Failed to dump content {self.path}, {e}.")
+			response = self.aes.encrypt(content)
+			if not response.success: return response
+			try:
+				content = utils.__save_bytes__(str(self.path), f"{self.format} ".encode()+response.encrypted)
+			except Exception as e: return r3sponse.error(f"Failed to save content {self.path}, {e}.")
+			return r3sponse.success(f"Successfully saved content {self.path}.")
+
+	# a dictionary data object
+	class Dictionary(Dictionary):
+		def __init__(self,
+			# the path.
+			path=None, 
+			# the default data, specify to call self.check() automatically.
+			default=None,
+			# the aes object.
+			aes=None,
+		):
+			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
+			self.base = FilePath(self.path).base()
+			self.aes = aes
+			Dictionary.__init__(self, path=self.path)
+		def load(self):
+			try:
+				format, content = unpack(Files.load(self.path))
+			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
+			response = self.aes.decrypt(content.encode())
+			if not response.success: return response
+			decrypted = response.decrypted.decode()
+			try:
+				content = json.loads(decrypted)
+			except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
+			self.dictionary = content
+			self.format = format
+			self.loaded = True
+			return r3sponse.success(f"Successfully loaded content {self.path}.")
+		def save(self):
+			if not self.loaded:
+				return r3sponse.error("The data object is not loaded yet, you must call content.load() first.")
+			try:
+				content = json.dumps(Formats.denitialize(self.dictionary))
+			except Exception as e: return r3sponse.error(f"Failed to dump content {self.path}, {e}.")
+			response = self.aes.encrypt(content)
+			if not response.success: return response
+			try:
+				content = utils.__save_bytes__(str(self.path), f"{self.format} ".encode()+response.encrypted)
+			except Exception as e: return r3sponse.error(f"Failed to save content {self.path}, {e}.")
+			return r3sponse.success(f"Successfully saved content {self.path}.")
+
 
 """
 
