@@ -58,14 +58,16 @@ class RSA(object):
 		response = utils.__default_response__()
 
 		# set dir,
-		directory = self.directory
-		private_key_path = self.private_key
-		public_key_path = self.public_key
+		directory = str(self.directory)
+		private_key_path = str(self.private_key)
+		public_key_path = str(self.public_key)
 
 		# checks.
 		if not self.memory:
-			if log_level >= 0: loader = syst3m.console.Loader(f"Generating key {self.directory}")
+			if log_level >= 0: 
+				loader = syst3m.console.Loader(f"Generating key {self.directory}")
 			if Files.exists(directory): 
+				loader.stop(success=False)
 				response["error"] = f"Key [{directory}] already exists."
 				return response
 		else:
@@ -112,8 +114,8 @@ class RSA(object):
 		# initialize keys.
 		if self.passphrase == None:
 			try:
-				self.public_key_object = _RSA_.importKey(self.public_key_data)
-				self.private_key_object = _RSA_.importKey(self.private_key_data)
+				self.public_key_object = _RSA_.importKey(str(self.public_key_data))
+				self.private_key_object = _RSA_.importKey(str(self.private_key_data))
 			except ValueError as e:
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
@@ -121,8 +123,8 @@ class RSA(object):
 				return response
 		else:
 			try:
-				self.public_key_object = _RSA_.importKey(self.public_key_data)
-				self.private_key_object = _RSA_.importKey(self.private_key_data, passphrase=self.passphrase)
+				self.public_key_object = _RSA_.importKey(str(self.public_key_data))
+				self.private_key_object = _RSA_.importKey(str(self.private_key_data), passphrase=self.passphrase)
 			except ValueError as e:
 				if "Padding is incorrect" in str(e):
 					response["error"] = "Provided an incorrect passphrase."
